@@ -2,7 +2,7 @@ package Module::Install::XSUtil;
 
 use 5.005_03;
 
-$VERSION = '0.19';
+$VERSION = '0.20';
 
 use Module::Install::Base;
 @ISA     = qw(Module::Install::Base);
@@ -17,7 +17,7 @@ use File::Find;
 use constant _VERBOSE => $ENV{MI_VERBOSE} ? 1 : 0;
 
 my %ConfigureRequires = (
-    'ExtUtils::CBuilder' => 0.21, # for have_compiler()
+    # currently nothing
 );
 
 my %BuildRequires = (
@@ -95,11 +95,7 @@ sub _is_msvc{
             }
         }
 
-        local $@;
-        return $cc_available = eval{
-            require ExtUtils::CBuilder;
-            ExtUtils::CBuilder->new(quiet => 1)->have_compiler();
-        } ? 1 : 0;
+        return $cc_available = shift->can_cc();
     }
 }
 
@@ -146,10 +142,10 @@ sub cc_warnings{
 
         no warnings 'numeric';
         if($Config{gccversion} >= 4.00){
-            $self->cc_append_to_ccflags('-Wextra -Wdeclaration-after-statement');
+            $self->cc_append_to_ccflags('-Wextra -Wdeclaration-after-statement -Wc++-compat');
         }
         else{
-            $self->cc_append_to_ccflags('-W');
+            $self->cc_append_to_ccflags('-W -Wno-comment');
         }
     }
     elsif(_is_msvc()){
@@ -537,7 +533,7 @@ Module::Install::XSUtil - Utility functions for XS modules
 
 =head1 VERSION
 
-This document describes Module::Install::XSUtil version 0.19.
+This document describes Module::Install::XSUtil version 0.20.
 
 =head1 SYNOPSIS
 
